Module loop_select

Module loop_select 

Cooperative poll-loop multiplexing multiple futures.

Structs

LoopSelectUnpin
Future that runs multiple poll functions in a loop until one of them returns ControlFlow::Break.

Functions

loop_select
Run multiple poll functions in a loop until one of them returns ControlFlow::Break. All functions have access to a mutable reference to the same data.

Type Aliases

LoopSelectPollFn
Type alias for the poll function signature used in loop_select.