Cooperative poll-loop multiplexing multiple futures.
Structs
- Loop
Select Unpin - Future that runs multiple poll functions in a loop until one of them returns
ControlFlow::Break.
Functions
- loop_
select - Run multiple poll functions in a loop until one of them returns
ControlFlow::Break. All functions have access to a mutable reference to the same data.
Type Aliases
- Loop
Select Poll Fn - Type alias for the poll function signature used in
loop_select.