pub fn loop_select<Data: Unpin, Ret, const N: usize>(
data: &mut Data,
poll_fns: [LoopSelectPollFn<Data, Ret>; N],
) -> LoopSelectUnpin<'_, Data, Ret, N> ⓘExpand description
Run multiple poll functions in a loop until one of them returns ControlFlow::Break.
All functions have access to a mutable reference to the same data.
A poll function should return ControlFlow::Continue(()) if it made progress,
or ControlFlow::Break(output) to finish the loop with the given output.